<?php

declare(strict_types=1);

namespace Drupal\cheeseburger_menu\Plugin\Deriver;

use Drupal\cheeseburger_menu\Plugin\Menu\LanguageSwitchMenuLink;
use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a deriver for each language.
 */
class LanguageSwitchLinksDeriver extends DeriverBase implements ContainerDeriverInterface {

  /**
   * LanguageSwitchLinksDeriver constructor.
   *
   * @param \Drupal\Core\Language\LanguageManagerInterface $languageManager
   *   Language manager.
   */
  public function __construct(protected LanguageManagerInterface $languageManager) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id): static {
    return new static(
      $container->get('language_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition): array {
    $plugin_definitions = [];
    $languages = $this->languageManager->getLanguages();
    foreach ($languages as $language) {
      $plugin_id = "language_switch_{$language->getId()}";
      $plugin_definitions[$plugin_id] = [
        'id' => $plugin_id,
        'menu_name' => 'language',
        'class' => LanguageSwitchMenuLink::class,
        'provider' => 'cheeseburger_menu',
        'options' => [
          'langcode' => $language->getId(),
        ],
        'metadata' => $language->getId(),
        'weight' => $language->getWeight(),
      ];
    }
    return $plugin_definitions;
  }

}
